	   
.. image:: _static/masterpiece.png
    :alt: Masterpiece - A Piece of Work
    :width: 320px
    :align: center
	    
Welcome to MasterPiece documentation!
=====================================

Classes
-------

.. inheritance-diagram::
   masterpiece.masterpiece 
   masterpiece.composite.Composite 
   masterpiece.application.Application 
   masterpiece.plugin.Plugin 
   masterpiece.plugmaster.PlugMaster 
   masterpiece.argmaestro.ArgMaestro 
   masterpiece.log.Log 
   masterpiece.treevisualizer.TreeVisualizer
   masterpiece.format.Format
   masterpiece.jsonformat.JsonFormat
   masterpiece.masterpiecethread.MasterPieceThread
   masterpiece.mqtt.Mqtt
   masterpiece.timeseries.TimeSeries
   masterpiece.url.URL
   :parts: 1

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   masterpiece/index

.. include:: README.rst
.. include:: LICENSE.rst
.. include:: CONTRIBUTING.rst
.. include:: CHANGELOG.rst
.. include:: TODO.rst

.. include:: tutorial.rst
.. include:: plugintutorial.rst
	     


Index
=====

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
